:mod:`art.preprocessing.expectation_over_transformation`
========================================================
.. automodule:: art.preprocessing.expectation_over_transformation

EOT Image Rotation - TensorFlow V2
----------------------------------
.. autoclass:: EOTImageRotationTensorFlowV2
   :members:
   :special-members:
